<?php declare (strict_types = 1);

namespace Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\Support\Arr;
use SimpleXMLIterator;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\ItemParser;
use Infomaker\Everyware\NewsML\Parsers\ObjectParser;

/**
 * GroupParser
 *
 * @link    http://infomaker.se
 * @package Infomaker\Everyware\NewsML\Parsers
 * @since   Infomaker\Everyware\NewsML\Parsers\GroupParser 1.0.0
 */
class MetaDataParser implements ItemParser
{

    public const TAG = 'metadata';

    /**
     * @var ItemParser[]
     */
    /**
     * @var array
     */
    private $parsers;

    public function __construct(ObjectParser $objectParser)
    {
        $this->parsers = [
            ObjectParser::TAG => $objectParser,
        ];
    }

    public function parse(SimpleXMLIterator $element): array
    {
        $items = [];

        foreach ($element as $tag => $item) {
            $parser = Arr::get($this->parsers, $tag, null);
            if ($parser instanceof ItemParser) {
                $items[] = $parser->parse($item);
            }
        }

        return Arr::flatten($items, 1);
    }
}
