<?php

namespace Spec\Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Item;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\ItemParser;
use Infomaker\Everyware\NewsML\Parsers\Interfaces\TypeParser;
use Infomaker\Everyware\NewsML\Parsers\MapEmbedParser;
use PhpSpec\Exception\Example\FailureException;
use PhpSpec\ObjectBehavior;
use Prophecy\Argument;
use function Spec\newsML\loadNewsMLFile;

class MapEmbedParserSpec extends ObjectBehavior
{
    function it_is_initializable()
    {
        $this->shouldHaveType(MapEmbedParser::class);
        $this->shouldImplement(ItemParser::class);
        $this->shouldImplement(TypeParser::class);
    }

    public function it_should_return_its_type()
    {
        $this->typeToParse()->shouldReturn('x-im/mapembed');
    }

    public function it_should_parse_the_object()
    {
        $xml = simplexml_load_string(loadNewsMLFile('mapembed'), 'SimpleXMLIterator');
        $this->parse($xml)->shouldReturnValidItem([
            'id' => 'MTc0LDQwLDI5LDE3MA',
            'type' => 'x-im/mapembed',
            'zoom' => 11,
            'geometry' => 'POINT (16.35677910000004 56.6634447)'
        ]);
    }

    public function getMatchers(): array
    {
        return [
            'returnValidItem' => static function ($subjects, $values) {
                if (empty($subjects)) {
                    throw new FailureException('Did not return any parsed items.');
                }

                $subject = $subjects[0];

                if ( ! $subject instanceof Item) {
                    throw new FailureException(sprintf('Failed to parse the object into a "%s".', Item::class));
                }

                if ($subject->getItemAttributes() !== $values) {
                    throw new FailureException(implode(PHP_EOL, [
                            'The Item did not contain desired properties.',
                            'expected ',
                            json_encode($values, JSON_PRETTY_PRINT),
                            'but got ',
                            $subject->toJson(JSON_PRETTY_PRINT)
                        ])
                    );
                }

                return true;
            },
        ];
    }
}
