<?php

namespace Spec\Infomaker\Everyware\NewsML\Parsers;


use Infomaker\Everyware\NewsML\Parsers\Metadata\ContactInfoParser;
use Infomaker\Everyware\NewsML\Parsers\Metadata\PolygonParser;
use Infomaker\Everyware\NewsML\Parsers\Metadata\PersonParser;
use Infomaker\Everyware\NewsML\Parsers\ObjectParser;
use PhpSpec\ObjectBehavior;
use Infomaker\Everyware\NewsML\Item;
use Infomaker\Everyware\NewsML\Parsers\MetaDataParser;

class MetaDataParserSpec extends ObjectBehavior
{
    function let()
    {
        $objectParsers = [
            PersonParser::OBJECT_TYPE => new PersonParser(),
            PolygonParser::OBJECT_TYPE => new PolygonParser(),
            ContactInfoParser::OBJECT_TYPE => new ContactInfoParser(),
        ];
        $this->beConstructedWith(new ObjectParser($objectParsers));
    }
    function it_is_initializable()
    {
        $this->shouldHaveType(MetaDataParser::class);
    }
    public function it_should_return_contact_info()
    {
        $xml = '
        <metadata>
            <object type="x-im/contact-info">
                <data>
                    <email>test@mail.com</email>
                    <phone>111222333</phone>
                    <mobile>444555666</mobile>
                </data>
            </object>
            </metadata>';
        $el = simplexml_load_string($xml, 'SimpleXMLIterator');
        $this->parse($el)->shouldHaveArrayValuesAndKeys([
            'type' => 'x-im/contact-info',
            'email' => 'test@mail.com',
            'phone' => '111222333',
            'mobile' => '444555666',
        ]);
    }
    public function it_should_return_geometry()
    {
        $xml = '
        <metadata>
            <object type="x-im/polygon">
            <data>
                <geometry>123.00.111</geometry>
            </data>
            </object>
        </metadata>
       ';
        $el = simplexml_load_string($xml, 'SimpleXMLIterator');

        $this->parse($el)
            ->shouldHaveArrayValuesAndKeys([
                'type' => 'x-im/polygon',
                'geometry' => '123.00.111',
            ]);
    }
    public function it_should_return_an_empty_array()
    {
        $xmlWithoutDataProp = '
        <metadata>
            <object type="x-im/polygon">
            </object>
        </metadata>
       ';
        $xmlWithEmptyDataProp = '
        <metadata>
            <object type="x-im/polygon">
            <data></data>
            </object>
        </metadata>
       ';
        $xmlEmpty = '<xml></xml>';
        $elWithoutData = simplexml_load_string($xmlWithoutDataProp, 'SimpleXMLIterator');
        $elWithEmptyData = simplexml_load_string($xmlWithEmptyDataProp, 'SimpleXMLIterator');
        $elEmpty = simplexml_load_string($xmlEmpty, 'SimpleXMLIterator');

        $this->parse($elWithoutData)
            ->shouldReturn([]);
        $this->parse($elWithEmptyData)
            ->shouldReturn([]);
        $this->parse($elEmpty)
            ->shouldReturn([]);
    }
    public function getMatchers(): array
    {
        return [
            'haveArrayValuesAndKeys' => function ($subject, $expectedValues) {
                return ($subject[0]->getProperties() === $expectedValues) && ($subject[0] instanceof Item);
            },
        ];
    }
}
