<?php

namespace Spec\Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Parsers\PdfParser;
use Infomaker\Everyware\NewsML\Item;
use PhpSpec\ObjectBehavior;
use Prophecy\Argument;

class PdfParserSpec extends ObjectBehavior
{
    function it_is_initializable()
    {
        $this->shouldHaveType(PdfParser::class);
    }
    public function it_should_parse_an_element()
    {
        $xml = '
            <object id="MjIxLDExNywyMzMsMTg" uuid="05bfe2e4-3666-5466-90bb-2997e6a9f0ef" type="x-im/pdf">
                <links>
                    <link rel="self" type="x-im/pdf" uri="im://pdf/WwPM7He0FoBdbY4nDTOUKq7cxt0.pdf" uuid="05bfe2e4-3666-5466-90bb-2997e6a9f0ef">
                        <data>
                            <text>pdf-test.pdf</text>
                        </data>
                    </link>
                </links>
            </object>
            ';
        $el = simplexml_load_string($xml, 'SimpleXMLIterator');
        $this->parse($el)
            ->shouldHaveArrayValuesAndKeys([
                "id" => "MjIxLDExNywyMzMsMTg",
                "uuid" => "05bfe2e4-3666-5466-90bb-2997e6a9f0ef",
                "type" => "x-im/pdf",
                "title" => "pdf-test.pdf",
                "file" => "WwPM7He0FoBdbY4nDTOUKq7cxt0.pdf",
                "url" => "randomPdf/WwPM7He0FoBdbY4nDTOUKq7cxt0.pdf",
            ]);
    }
    public function it_should_parse_an_element_even_if_its_empty()
    {
        $xml = '
        <object id="MjIxLDExNywyMzMsMTg" uuid="05bfe2e4-3666-5466-90bb-2997e6a9f0ef" type="x-im/pdf">
        </object>
        ';
        $el = simplexml_load_string($xml, 'SimpleXMLIterator');
        $this->parse($el)
            ->shouldHaveArrayValuesAndKeys([
                'id' => 'MjIxLDExNywyMzMsMTg',
                'uuid' => '05bfe2e4-3666-5466-90bb-2997e6a9f0ef',
                'type' => 'x-im/pdf',
            ]);
    }
    public function it_should_return_its_type()
    {
        $this->typeToParse()->shouldReturn('x-im/pdf');
    }
    public function it_should_support_parsing_inline_tags()
    {
        $xml = '
            <object id="MjIxLDExNywyMzMsMTg" uuid="05bfe2e4-3666-5466-90bb-2997e6a9f0ef" type="x-im/pdf">
                <links>
                    <link rel="self" type="x-im/pdf" uri="im://pdf/WwPM7He0FoBdbY4nDTOUKq7cxt0.pdf" uuid="05bfe2e4-3666-5466-90bb-2997e6a9f0ef">
                        <data>
                            <text><strong id="strong-00421cfcbbb61c85b0318309541f84be"><em id="emphasis-b6447ce0314152526e1024f6e7e3067f">pdf-test.pdf</em></strong></text>
                        </data>
                    </link>
                </links>
            </object>
            ';
        $el = simplexml_load_string($xml, 'SimpleXMLIterator');
        $this->parse($el)
            ->shouldHaveArrayValuesAndKeys([
                "id" => "MjIxLDExNywyMzMsMTg",
                "uuid" => "05bfe2e4-3666-5466-90bb-2997e6a9f0ef",
                "type" => "x-im/pdf",
                "title" => "<strong id=\"strong-00421cfcbbb61c85b0318309541f84be\"><em id=\"emphasis-b6447ce0314152526e1024f6e7e3067f\">pdf-test.pdf</em></strong>",
                "file" => "WwPM7He0FoBdbY4nDTOUKq7cxt0.pdf",
                "url" => "randomPdf/WwPM7He0FoBdbY4nDTOUKq7cxt0.pdf",
            ]);
    }

    public function getMatchers(): array
    {
        return [
            'haveArrayValuesAndKeys' => function ($subject, $values) {
                return ($subject[0]->getItemAttributes() === $values) && ($subject[0] instanceof Item);
            },
        ];
    }
}
