<?php

namespace Spec\Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Parsers\YouplayParser;
use Infomaker\Everyware\NewsML\Item;
use PhpSpec\ObjectBehavior;
use Prophecy\Argument;

class YouplayParserSpec extends ObjectBehavior
{
    function it_is_initializable()
    {
        $this->shouldHaveType(YouplayParser::class);
    }
    public function it_should_parse_an_element()
    {
    
        $xml = '
            <object id="youplayembed-520ee6fcf2b9d2376c41b89cf10d98d7" type="x-im/youplay" uri="x-im://youplay/watch?v=htqjcfSrQsA" url="https://www.youplay.com/watch?v=htqjcfSrQsA">
                <data>
                    <start>0</start>
                    <embedCode></embedCode>
                </data>
                <links>
                    <link rel="alternate" title="Click link to view content" type="text/html" url="https://www.youplay.com/watch?v=htqjcfSrQsA">
                        <data>
                            <context>Video</context>
                            <provider>YouPlay</provider>
                        </data>
                    </link>
                    <link rel="alternate" type="image/jpg" url="https://i.ytimg.com/vi/htqjcfSrQsA/hqdefault.jpg">
                        <data>
                            <width>480</width>
                            <height>360</height>
                        </data>
                    </link>
                </links>
            </object>';
        $el = simplexml_load_string($xml, 'SimpleXMLIterator');
        $this->parse($el)
            ->shouldHaveArrayKey([
                'id' => 'youplayembed-520ee6fcf2b9d2376c41b89cf10d98d7',
                'type' => 'x-im/youplay',
                'uri' => 'x-im://youplay/watch?v=htqjcfSrQsA',
                'url' => 'https://www.youplay.com/watch?v=htqjcfSrQsA',
                'start' => '0',
                'embedCode' => '',
                'config' => [],
                'video' => [
                    'url' => 'https://delivery.youplay.se/videos/watch?v=htqjcfSrQsA/720?fmt=mp4',
                    'format' => 'mp4'
                ],
                'api_url' => '',
                'thumb' => [
                    'width' => '480',
                    'height' => '360',
                    'url' => 'https://i.ytimg.com/vi/htqjcfSrQsA/hqdefault.jpg',
                    'format' => 'jpg'
                ],
            ]);
    }
    public function it_should_return_its_type()
    {
        $this->typeToParse()->shouldReturn('x-im/youplay');
    }
    public function getMatchers(): array
    {
        return [
            'haveArrayKey' => function ($subject, $values) {
                return ($subject[0]->getItemAttributes() === $values) && ($subject[0] instanceof Item);
            },
        ];
    }
}
